| Title: | Tools for Evaluating Diagnostic Test Performance |
|---|---|
| Description: | Evaluates diagnostic test performance using data from laboratory or diagnostic research. It includes functions to compute common performance indicators along with their confidence intervals, and offers an interactive 'shiny' application for comprehensive analysis including ROC curve visualization and related metrics. It supports both binary and continuous test variables. It allows users to compute key performance indicators and visualize Receiver Operating Characteristic (ROC) curves, determine optimal cut-off thresholds, display confusion matrix, and export publication-ready plot. It aims to facilitate the application of statistical methods in diagnostic test evaluation by healthcare professionals. Methodological details and references for the computation of performance indicators are provided in the package vignette. |
| Authors: | Nassim AYAD [aut, cre] (ORCID: <https://orcid.org/0000-0002-1809-0935>, affiliation: Laboratory of Modeling and Biostatistics, Pasteur Institute of Algeria) |
| Maintainer: | Nassim AYAD <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.0.6 |
| Built: | 2026-05-22 08:24:15 UTC |
| Source: | https://github.com/nassimayad87/evaltest |
This function computes sensitivity, specificity, predictive values, likelihood ratios, accuracy, and Youden index with their confidence intervals (with desired confidence level), based on a 2x2 table of diagnostic test results.
compute_indicators(tp, fp, fn, tn, prev, conf = 0.95)compute_indicators(tp, fp, fn, tn, prev, conf = 0.95)
tp |
True positives |
fp |
False positives |
fn |
False negatives |
tn |
True negatives |
prev |
Prevalence (numeric between 0 and 1) |
conf |
Confidence level (default 0.95) |
A list with all diagnostic indicators and confidence intervals
compute_indicators(58, 15, 14, 26, prev = 0.1, conf = 0.95)compute_indicators(58, 15, 14, 26, prev = 0.1, conf = 0.95)
This function starts the Shiny application included in the EvalTest package, which aims to evaluate diagnostic tests performance.
run_app()run_app()
The function does not return a value; it launches a Shiny application.
if (interactive()) { library(EvalTest) run_app() }if (interactive()) { library(EvalTest) run_app() }